.. _all-salt.modules:

============================
Full list of builtin modules
============================

.. admonition:: Virtual modules

    .. toctree::

        salt.modules.pkg
        salt.modules.sys

.. currentmodule:: salt.modules

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aliases
    apache
    apt
    archive
    at
    augeas_cfg
    bluez
    brew
    butterkvm
    ca
    cassandra
    cluster
    cmdmod
    config
    cp
    cron
    data
    debconfmod
    debian_service
    disk
    djangomod
    ebuild
    event
    file
    freebsdjail
    freebsdkmod
    freebsdpkg
    freebsdservice
    gem
    gentoo_service
    git
    grains
    groupadd
    grub
    hg
    hosts
    kmod
    kvm_hyper
    launchctl
    ldap
    linux_sysctl
    mdadm
    mongodb
    monit
    moosefs
    mount
    mysql
    network
    nginx
    nzbget
    openbsdpkg
    openbsdservice
    osxdesktop
    pacman
    pecl
    pillar
    pip
    pkgng
    postgres
    poudriere
    ps
    publish
    puppet
    pw_group
    pw_user
    rabbitmq_server
    reg
    rh_ip
    rh_service
    rvm
    saltutil
    selinux
    service
    shadow
    smf
    solr
    sqlite3
    ssh
    state
    status
    supervisord
    systemd
    test
    tomcat
    upstart
    useradd
    virt
    virtualenv
    win_disk
    win_file
    win_groupadd
    win_network
    win_pkg
    win_service
    win_shadow
    win_useradd
    yumpkg
    yumpkg5
    zpool
    zypper
